@@ -19,7 +19,6 @@ import netaddr
 from neutronclient.common import exceptions as neutron_exception
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_utils import timeutils
 
 from ec2api.api import address as address_api
 from ec2api.api import common
@@ -48,7 +47,22 @@ def create_network_interface(context, subnet_id,
                              private_ip_addresses=None,
                              secondary_private_ip_address_count=None,
                              description=None,
-                             security_group_id=None):
+                             security_group_id=None,
+                             client_token=None):
+
+    if client_token:
+        result = describe_network_interfaces(context,
+                                   filter=[{'name': 'client-token',
+                                            'value': [client_token]}])
+        if result['networkInterfaceSet']:
+            if len(result['networkInterfaceSet']) > 1:
+                LOG.error('describe_network_interfaces returns %s '
+                          'network_interfaces, but 1 is expected.',
+                          len(result['networkInterfaceSet']))
+                LOG.error('Requested client token: %s', client_token)
+                LOG.error('Result: %s', result)
+            return result['networkInterfaceSet'][0]
+
     subnet = ec2utils.get_db_item(context, subnet_id)
     if subnet is None:
         raise exception.InvalidSubnetIDNotFound(id=subnet_id)
@@ -207,6 +221,7 @@ class NetworkInterfaceDescriber(common.TaggableItemsDescriber):
                   'attachment.attach.time': ('attachment', 'attachTime'),
                   'attachment.delete-on-termination': ('attachment',
                                                        'deleteOnTermination'),
+                  'client-token': 'clientToken',
                   'description': 'description',
                   'group-id': ['groupSet', 'groupId'],
                   'group-name': ['groupSet', 'groupName'],
@@ -554,7 +569,7 @@ def _attach_network_interface_item(context, network_interface, instance_id,
                                    device_index, attach_time=None,
                                    delete_on_termination=False):
     if not attach_time:
-        attach_time = timeutils.isotime(None, True)
+        attach_time = ec2utils.isotime(None, True)
     network_interface.update({
         'instance_id': instance_id,
         'device_index': device_index,
